@@ -17,6 +17,11 @@ Source code at https://github.com/alonely0/voila"#,
     version_short = "v"
 )]
 pub struct Cli {
+    #[structopt(
+        long,
+        help = "Compile Voila script into a static binary embedding all runtime"
+    )]
+    pub compile: bool,
     #[structopt(
         short,
         long,
